@@ -10,6 +10,7 @@
 #include <libgnomeui/gnome-window-icon.h>
 
 #include "gnome-calc.h"
+#include "sr.h"
 
 /* values for selection info */
 enum {
@@ -28,8 +29,14 @@ about_cb (GtkWidget *widget, gpointer data)
 	static GtkWidget *about = NULL;
 	gchar *authors[] = {
 		"George Lebl <jirka@5z.com>",
+		"Bastien Nocera <hadess@hadess.net> (fixes)",
 		NULL
 	};
+	gchar *documenters[] = {
+		NULL
+	};
+	/* Translator credits */
+	gchar *translator_credits = _("");
 
 	if (about != NULL)
 	{
@@ -37,11 +44,13 @@ about_cb (GtkWidget *widget, gpointer data)
 		gdk_window_raise(about->window);
 		return;
 	}
-	about = gnome_about_new(_("The Gnome Calculator"), VERSION,
+	about = gnome_about_new(_("The GNOME Calculator"), VERSION,
 				"(C) 1998 the Free Software Foundation",
-				(const char **)authors,
 				_("Simple double precision calculator similiar "
 				  "to xcalc"),
+				(const char **)authors,
+				(const char **)documenters,
+				(const char *)translator_credits,
 				NULL);
 	gtk_signal_connect(GTK_OBJECT(about), "destroy",
 			   GTK_SIGNAL_FUNC(gtk_widget_destroyed), &about);
@@ -116,6 +125,15 @@ static GnomeUIInfo gcalc_menu[] = {
         GNOMEUIINFO_END
 };
 
+static gboolean analog = FALSE;
+
+struct poptOption options [] = {
+  { "analog", '\0', POPT_ARG_NONE|POPT_ARGFLAG_ONEDASH, &analog, 0,
+    N_("Run in analog (slide rule) mode"), NULL },
+  POPT_AUTOHELP
+  { NULL, 0, 0, NULL, 0}
+};
+
 
 int
 main(int argc, char *argv[])
@@ -128,12 +146,20 @@ main(int argc, char *argv[])
 	static gint n_targets = sizeof(targets) / sizeof(targets[0]);
 	
 	/* Initialize the i18n stuff */
-	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
-	textdomain (PACKAGE);
+	bindtextdomain(GETTEXT_PACKAGE, GNOMELOCALEDIR);
+	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
+	textdomain(GETTEXT_PACKAGE);
 
-	gnome_init ("gcalc", VERSION, argc, argv);
+	gnome_program_init ("gcalc", VERSION, LIBGNOMEUI_MODULE,
+			argc, argv, GNOME_PARAM_POPT_TABLE, options, NULL);
 	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-calc2.png");
-        app=gnome_app_new("gcalc", _("Gnome Calculator"));
+
+	if (analog) {
+		run_slide_rule ();
+		return 0;
+	}
+
+        app = gnome_app_new("gcalc", _("GNOME Calculator"));
 	gtk_window_set_wmclass (GTK_WINDOW (app), "gcalc", "gcalc");
 	gtk_window_set_policy (GTK_WINDOW (app), FALSE, TRUE, FALSE);
 
@@ -141,7 +167,7 @@ main(int argc, char *argv[])
 			GTK_SIGNAL_FUNC(quit_cb), NULL);
 
 	/*set up the menu*/
-        gnome_app_create_menus(GNOME_APP(app), gcalc_menu);
+        gnome_app_create_menus_with_data(GNOME_APP(app), gcalc_menu, app);
 
 	calc = gnome_calc_new();
 	gnome_calc_bind_extra_keys (GNOME_CALC (calc), GTK_WIDGET (app));
